@@ -1,25 +1,23 @@
 use {
-    crate::{state::*, errors::*},
+    crate::{state::*, errors::ErrorCode},
     anchor_lang::{prelude::*, AccountsClose},
     cardinal_token_manager::{state::{TokenManager, TokenManagerState, InvalidationType}},
 };
 
 #[derive(Accounts)]
 pub struct CloseCtx<'info> {
+    /// CHECK: This is not dangerous because we expect it to potentially be empty
     #[account(constraint = token_manager.key() == time_invalidator.token_manager @ ErrorCode::InvalidTokenManager)]
     token_manager: UncheckedAccount<'info>,
 
-    #[account(
-        mut,
-        seeds = [TIME_INVALIDATOR_SEED.as_bytes(), token_manager.key().as_ref()], bump = time_invalidator.bump,
-    )]
+    #[account(mut)]
     time_invalidator: Box<Account<'info, TimeInvalidator>>,
 
     #[account(mut)]
     closer: Signer<'info>,
 }
 
-pub fn handler(ctx: Context<CloseCtx>) -> ProgramResult {
+pub fn handler(ctx: Context<CloseCtx>) -> Result<()> {
     if ctx.accounts.token_manager.data_is_empty() {
         ctx.accounts.time_invalidator.close(ctx.accounts.closer.to_account_info())?;
     } else {
@@ -27,7 +25,7 @@ pub fn handler(ctx: Context<CloseCtx>) -> ProgramResult {
         if token_manager.state == TokenManagerState::Initialized as u8 && ctx.accounts.closer.key() == token_manager.issuer {
             ctx.accounts.time_invalidator.close(ctx.accounts.closer.to_account_info())?;
         }
-        if token_manager.state == TokenManagerState::Invalidated as u8 && token_manager.invalidation_type != InvalidationType::Invalidate as u8 {
+        if token_manager.state == TokenManagerState::Invalidated as u8 && token_manager.kind != InvalidationType::Invalidate as u8 {
             ctx.accounts.time_invalidator.close(ctx.accounts.closer.to_account_info())?;
         }
     }
